# babel-preset-es2015-tiny

这是一个 Babel preset, 它是 [ES2015 preset](http://babeljs.io/docs/plugins/preset-es2015/) 的子集。

它不包含下面这些 ES2015 preset 中的 transform 插件:

 - [babel-plugin-transform-es2015-duplicate-keys](http://babeljs.io/docs/plugins/transform-es2015-duplicate-keys/)
 - [babel-plugin-transform-es2015-for-of](http://babeljs.io/docs/plugins/transform-es2015-for-of/)
 - [babel-plugin-transform-es2015-typeof-symbol](http://babeljs.io/docs/plugins/transform-es2015-typeof-symbol/)
 - [babel-plugin-transform-regenerator](http://babeljs.io/docs/plugins/transform-regenerator/)

## 为什么要这样做?

当你结合 [transform-runtime](http://babeljs.io/docs/plugins/transform-runtime/) 一起使用 ES2015 preset 的时候,
`Symbol` shim 会被加入到最终的打包文件中,
即使你的项目里完全没有用到过它。

为了避免这个情况, 所以需要删除与 Symbol 相关的 transform 插件, 详情见[这篇博文](https://github.com/lmk123/blog/issues/46)。

**如果你的项目里没有用到 `for...of`、`Symbol`、Generators 函数和 async/await, 你可以使用 es2015-tiny 来减小最终文件体积。**

## 安装

```
$ npm install --save-dev babel-preset-es2015-tiny
```

## 使用

### 配置 `.babelrc` (推荐)

```json
{
  "presets": ["es2015-tiny"]
}
```

### 命令行

```
$ babel script.js --presets es2015-tiny
```

### Node API

```javascript
require("babel-core").transform("code", {
  presets: ["es2015-tiny"]
});
```
